@@ -1,6 +1,5 @@
 # coding:utf-8
 from __future__ import print_function
-from volcengine.imagex.data.ImageXData import *
 from volcengine.imagex.ImageXService import ImageXService
 
 if __name__ == '__main__':
@@ -16,6 +15,5 @@ if __name__ == '__main__':
     query['EndTime'] = "2023-01-28T00:00:00+08:00"
     query['Interval'] = "300"
 
-    resp = describe_imagex_cdntop_request_data(imagex_service, query)
+    resp = imagex_service.describe_imagex_cdntop_request_data(query)
     print(resp)
-
